@@ -4,12 +4,16 @@ import requests
 import datetime
 import schedule
 import time
-from itertools import groupby
-from operator import itemgetter
-import RPi.GPIO as GPIO
 
-HALF_POWER_HOURS = 8
-ZERO_POWER_HOURS = 6
+try:
+    import RPi.GPIO as GPIO
+except RuntimeError as e:
+    if e.args[0] == "This module can only be run on a Raspberry Pi!":
+        print("RPi.GPIO not found, using dummy GPIO")
+        import Mock.GPIO as GPIO
+
+HALF_POWER_HOURS = 3
+ZERO_POWER_HOURS = 2
 MAX_ULTIMATE_LOWEST_PRICE_HOURS = 5
 MAX_CONSECUTIVE_ZERO_POWER_HOURS = 2
 ULTIMATE_LOWEST_PRICE = 0.03
@@ -35,7 +39,7 @@ class HourPrices:
     # Get hour prices for today from curl -X GET "https://api.spot-hinta.fi/Today" -H  "accept: application/json"
     def __set_hour_prices(self, tomorrow=False):
         if tomorrow:
-            url = "https://api.spot-hinta.fi/Tomorrow"
+            url = "https://api.spot-hinta.fi/DayForward"
         else:
             url = "https://api.spot-hinta.fi/Today"
 
@@ -220,7 +224,7 @@ class HeatControl:
 
         for hour in self.HalfPowerHours:
             if hour["Hour"] == datetime.datetime.now().hour:
-                # self.set_heat_50_percent()
+                self.set_heat_50_percent()
                 print(str(datetime.datetime.now()) + ": Half power")
                 reset_heat = False
                 break
